@@ -4,13 +4,15 @@ from .google_trans import GoogleTranslator
 from .pons import PonsTranslator
 from .linguee import LingueeTranslator
 from .mymemory import MyMemoryTranslator
+from .detection import detect_language
 
 
 __author__ = """Nidhal Baccouri"""
 __email__ = 'nidhalbacc@gmail.com'
-__version__ = '1.1.2'
+__version__ = '1.1.3'
 
 __all__ = [GoogleTranslator,
            PonsTranslator,
            LingueeTranslator,
-           MyMemoryTranslator]
+           MyMemoryTranslator,
+           detect_language]
